==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/BuildStrategyFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface BuildStrategyFluent<A extends io.fabric8.openshift.api.model.BuildStrategyFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCustomStrategy instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.CustomBuildStrategy getCustomStrategy();
  public io.fabric8.openshift.api.model.CustomBuildStrategy buildCustomStrategy();
  public A withCustomStrategy(io.fabric8.openshift.api.model.CustomBuildStrategy customStrategy);
  public java.lang.Boolean hasCustomStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.CustomStrategyNested<A> withNewCustomStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.CustomStrategyNested<A> withNewCustomStrategyLike(io.fabric8.openshift.api.model.CustomBuildStrategy item);
  public io.fabric8.openshift.api.model.BuildStrategyFluent.CustomStrategyNested<A> editCustomStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.CustomStrategyNested<A> editOrNewCustomStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.CustomStrategyNested<A> editOrNewCustomStrategyLike(io.fabric8.openshift.api.model.CustomBuildStrategy item);
  
  /**
   * This method has been deprecated, please use method buildDockerStrategy instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.DockerBuildStrategy getDockerStrategy();
  public io.fabric8.openshift.api.model.DockerBuildStrategy buildDockerStrategy();
  public A withDockerStrategy(io.fabric8.openshift.api.model.DockerBuildStrategy dockerStrategy);
  public java.lang.Boolean hasDockerStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.DockerStrategyNested<A> withNewDockerStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.DockerStrategyNested<A> withNewDockerStrategyLike(io.fabric8.openshift.api.model.DockerBuildStrategy item);
  public io.fabric8.openshift.api.model.BuildStrategyFluent.DockerStrategyNested<A> editDockerStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.DockerStrategyNested<A> editOrNewDockerStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.DockerStrategyNested<A> editOrNewDockerStrategyLike(io.fabric8.openshift.api.model.DockerBuildStrategy item);
  
  /**
   * This method has been deprecated, please use method buildJenkinsPipelineStrategy instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategy getJenkinsPipelineStrategy();
  public io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategy buildJenkinsPipelineStrategy();
  public A withJenkinsPipelineStrategy(io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategy jenkinsPipelineStrategy);
  public java.lang.Boolean hasJenkinsPipelineStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.JenkinsPipelineStrategyNested<A> withNewJenkinsPipelineStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.JenkinsPipelineStrategyNested<A> withNewJenkinsPipelineStrategyLike(io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategy item);
  public io.fabric8.openshift.api.model.BuildStrategyFluent.JenkinsPipelineStrategyNested<A> editJenkinsPipelineStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.JenkinsPipelineStrategyNested<A> editOrNewJenkinsPipelineStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.JenkinsPipelineStrategyNested<A> editOrNewJenkinsPipelineStrategyLike(io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategy item);
  
  /**
   * This method has been deprecated, please use method buildSourceStrategy instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SourceBuildStrategy getSourceStrategy();
  public io.fabric8.openshift.api.model.SourceBuildStrategy buildSourceStrategy();
  public A withSourceStrategy(io.fabric8.openshift.api.model.SourceBuildStrategy sourceStrategy);
  public java.lang.Boolean hasSourceStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.SourceStrategyNested<A> withNewSourceStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.SourceStrategyNested<A> withNewSourceStrategyLike(io.fabric8.openshift.api.model.SourceBuildStrategy item);
  public io.fabric8.openshift.api.model.BuildStrategyFluent.SourceStrategyNested<A> editSourceStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.SourceStrategyNested<A> editOrNewSourceStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.SourceStrategyNested<A> editOrNewSourceStrategyLike(io.fabric8.openshift.api.model.SourceBuildStrategy item);
  public java.lang.String getType();
  public A withType(java.lang.String type);
  public java.lang.Boolean hasType();
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0);
  public interface CustomStrategyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.CustomBuildStrategyFluent<io.fabric8.openshift.api.model.BuildStrategyFluent.CustomStrategyNested<N>>{
    public N and();
    public N endCustomStrategy();
    
  }
  public interface DockerStrategyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.DockerBuildStrategyFluent<io.fabric8.openshift.api.model.BuildStrategyFluent.DockerStrategyNested<N>>{
    public N and();
    public N endDockerStrategy();
    
  }
  public interface JenkinsPipelineStrategyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategyFluent<io.fabric8.openshift.api.model.BuildStrategyFluent.JenkinsPipelineStrategyNested<N>>{
    public N and();
    public N endJenkinsPipelineStrategy();
    
  }
  public interface SourceStrategyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.SourceBuildStrategyFluent<io.fabric8.openshift.api.model.BuildStrategyFluent.SourceStrategyNested<N>>{
    public N and();
    public N endSourceStrategy();
    
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/BuildStrategyFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface BuildStrategyFluent<A extends io.fabric8.openshift.api.model.BuildStrategyFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCustomStrategy instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.CustomBuildStrategy getCustomStrategy();
  public io.fabric8.openshift.api.model.CustomBuildStrategy buildCustomStrategy();
  public A withCustomStrategy(io.fabric8.openshift.api.model.CustomBuildStrategy customStrategy);
  public java.lang.Boolean hasCustomStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.CustomStrategyNested<A> withNewCustomStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.CustomStrategyNested<A> withNewCustomStrategyLike(io.fabric8.openshift.api.model.CustomBuildStrategy item);
  public io.fabric8.openshift.api.model.BuildStrategyFluent.CustomStrategyNested<A> editCustomStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.CustomStrategyNested<A> editOrNewCustomStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.CustomStrategyNested<A> editOrNewCustomStrategyLike(io.fabric8.openshift.api.model.CustomBuildStrategy item);
  
  /**
   * This method has been deprecated, please use method buildDockerStrategy instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.DockerBuildStrategy getDockerStrategy();
  public io.fabric8.openshift.api.model.DockerBuildStrategy buildDockerStrategy();
  public A withDockerStrategy(io.fabric8.openshift.api.model.DockerBuildStrategy dockerStrategy);
  public java.lang.Boolean hasDockerStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.DockerStrategyNested<A> withNewDockerStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.DockerStrategyNested<A> withNewDockerStrategyLike(io.fabric8.openshift.api.model.DockerBuildStrategy item);
  public io.fabric8.openshift.api.model.BuildStrategyFluent.DockerStrategyNested<A> editDockerStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.DockerStrategyNested<A> editOrNewDockerStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.DockerStrategyNested<A> editOrNewDockerStrategyLike(io.fabric8.openshift.api.model.DockerBuildStrategy item);
  
  /**
   * This method has been deprecated, please use method buildJenkinsPipelineStrategy instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategy getJenkinsPipelineStrategy();
  public io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategy buildJenkinsPipelineStrategy();
  public A withJenkinsPipelineStrategy(io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategy jenkinsPipelineStrategy);
  public java.lang.Boolean hasJenkinsPipelineStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.JenkinsPipelineStrategyNested<A> withNewJenkinsPipelineStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.JenkinsPipelineStrategyNested<A> withNewJenkinsPipelineStrategyLike(io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategy item);
  public io.fabric8.openshift.api.model.BuildStrategyFluent.JenkinsPipelineStrategyNested<A> editJenkinsPipelineStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.JenkinsPipelineStrategyNested<A> editOrNewJenkinsPipelineStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.JenkinsPipelineStrategyNested<A> editOrNewJenkinsPipelineStrategyLike(io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategy item);
  
  /**
   * This method has been deprecated, please use method buildSourceStrategy instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SourceBuildStrategy getSourceStrategy();
  public io.fabric8.openshift.api.model.SourceBuildStrategy buildSourceStrategy();
  public A withSourceStrategy(io.fabric8.openshift.api.model.SourceBuildStrategy sourceStrategy);
  public java.lang.Boolean hasSourceStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.SourceStrategyNested<A> withNewSourceStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.SourceStrategyNested<A> withNewSourceStrategyLike(io.fabric8.openshift.api.model.SourceBuildStrategy item);
  public io.fabric8.openshift.api.model.BuildStrategyFluent.SourceStrategyNested<A> editSourceStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.SourceStrategyNested<A> editOrNewSourceStrategy();
  public io.fabric8.openshift.api.model.BuildStrategyFluent.SourceStrategyNested<A> editOrNewSourceStrategyLike(io.fabric8.openshift.api.model.SourceBuildStrategy item);
  public java.lang.String getType();
  public A withType(java.lang.String type);
  public java.lang.Boolean hasType();
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface CustomStrategyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.CustomBuildStrategyFluent<io.fabric8.openshift.api.model.BuildStrategyFluent.CustomStrategyNested<N>>{
    public N and();
    public N endCustomStrategy();
    
  }
  public interface DockerStrategyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.DockerBuildStrategyFluent<io.fabric8.openshift.api.model.BuildStrategyFluent.DockerStrategyNested<N>>{
    public N and();
    public N endDockerStrategy();
    
  }
  public interface JenkinsPipelineStrategyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategyFluent<io.fabric8.openshift.api.model.BuildStrategyFluent.JenkinsPipelineStrategyNested<N>>{
    public N and();
    public N endJenkinsPipelineStrategy();
    
  }
  public interface SourceStrategyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.SourceBuildStrategyFluent<io.fabric8.openshift.api.model.BuildStrategyFluent.SourceStrategyNested<N>>{
    public N and();
    public N endSourceStrategy();
    
  }
  
}
